@@ -21,7 +21,7 @@ function createAssertObject() {
     function verifyIsStub() {
         var args = arraySlice(arguments);
 
-        forEach(args, function(method) {
+        forEach(args, function (method) {
             if (!method) {
                 assert.fail("fake is not a spy");
             }
@@ -30,11 +30,11 @@ function createAssertObject() {
                 verifyIsStub(method.proxy);
             } else {
                 if (typeof method !== "function") {
-                    assert.fail(method + " is not a function");
+                    assert.fail(`${method} is not a function`);
                 }
 
                 if (typeof method.getCall !== "function") {
-                    assert.fail(method + " is not stubbed");
+                    assert.fail(`${method} is not stubbed`);
                 }
             }
         });
@@ -49,10 +49,9 @@ function createAssertObject() {
             case "calledThrice":
                 if (assertionArgs.length !== 0) {
                     assert.fail(
-                        assertionMethod +
-                            " takes 1 argument but was called with " +
-                            (assertionArgs.length + 1) +
-                            " arguments"
+                        `${assertionMethod} takes 1 argument but was called with ${
+                            assertionArgs.length + 1
+                        } arguments`
                     );
                 }
                 break;
@@ -75,7 +74,7 @@ function createAssertObject() {
             meth = name;
         }
 
-        assert[name] = function(fake) {
+        assert[name] = function (fake) {
             verifyIsStub(fake);
 
             var args = arraySlice(arguments, 1);
@@ -86,11 +85,20 @@ function createAssertObject() {
             if (typeof meth === "function") {
                 failed = !meth(fake);
             } else {
-                failed = typeof fake[meth] === "function" ? !fake[meth].apply(fake, args) : !fake[meth];
+                failed =
+                    typeof fake[meth] === "function"
+                        ? !fake[meth].apply(fake, args)
+                        : !fake[meth];
             }
 
             if (failed) {
-                failAssertion(this, (fake.printf || fake.proxy.printf).apply(fake, concat([msg], args)));
+                failAssertion(
+                    this,
+                    (fake.printf || fake.proxy.printf).apply(
+                        fake,
+                        concat([msg], args)
+                    )
+                );
             } else {
                 assert.pass(name);
             }
@@ -100,7 +108,9 @@ function createAssertObject() {
     function exposedName(prefix, prop) {
         return !prefix || /^fail/.test(prop)
             ? prop
-            : prefix + stringSlice(prop, 0, 1).toUpperCase() + stringSlice(prop, 1);
+            : prefix +
+                  stringSlice(prop, 0, 1).toUpperCase() +
+                  stringSlice(prop, 1);
     }
 
     assert = {
@@ -137,7 +147,10 @@ function createAssertObject() {
                     // If this fails, we'll just fall back to the blank string
                 }
 
-                failAssertion(this, "expected " + expected + " to be called in order but were called as " + actual);
+                failAssertion(
+                    this,
+                    `expected ${expected} to be called in order but were called as ${actual}`
+                );
             } else {
                 assert.pass("callOrder");
             }
@@ -146,8 +159,16 @@ function createAssertObject() {
         callCount: function assertCallCount(method, count) {
             verifyIsStub(method);
 
-            if (method.callCount !== count) {
-                var msg = "expected %n to be called " + timesInWords(count) + " but was called %c%C";
+            var msg;
+            if (typeof count !== "number") {
+                msg =
+                    `expected ${format(count)} to be a number ` +
+                    `but was of type ${typeof count}`;
+                failAssertion(this, msg);
+            } else if (method.callCount !== count) {
+                msg =
+                    `expected %n to be called ${timesInWords(count)} ` +
+                    `but was called %c%C`;
                 failAssertion(this, method.printf(msg));
             } else {
                 assert.pass("callCount");
@@ -160,12 +181,17 @@ function createAssertObject() {
             }
 
             var o = options || {};
-            var prefix = (typeof o.prefix === "undefined" && "assert") || o.prefix;
-            var includeFail = typeof o.includeFail === "undefined" || Boolean(o.includeFail);
+            var prefix =
+                (typeof o.prefix === "undefined" && "assert") || o.prefix;
+            var includeFail =
+                typeof o.includeFail === "undefined" || Boolean(o.includeFail);
             var instance = this;
 
-            forEach(Object.keys(instance), function(method) {
-                if (method !== "expose" && (includeFail || !/^(fail)/.test(method))) {
+            forEach(Object.keys(instance), function (method) {
+                if (
+                    method !== "expose" &&
+                    (includeFail || !/^(fail)/.test(method))
+                ) {
                     target[exposedName(prefix, method)] = instance[method];
                 }
             });
@@ -180,40 +206,91 @@ function createAssertObject() {
             } else {
                 var formatted = [
                     "expected value to match",
-                    "    expected = " + format(expectation),
-                    "    actual = " + format(actual)
+                    `    expected = ${format(expectation)}`,
+                    `    actual = ${format(actual)}`,
                 ];
 
                 failAssertion(this, join(formatted, "\n"));
             }
-        }
+        },
     };
 
-    mirrorPropAsAssertion("called", "expected %n to have been called at least once but was never called");
+    mirrorPropAsAssertion(
+        "called",
+        "expected %n to have been called at least once but was never called"
+    );
     mirrorPropAsAssertion(
         "notCalled",
-        function(spy) {
+        function (spy) {
             return !spy.called;
         },
         "expected %n to not have been called but was called %c%C"
     );
-    mirrorPropAsAssertion("calledOnce", "expected %n to be called once but was called %c%C");
-    mirrorPropAsAssertion("calledTwice", "expected %n to be called twice but was called %c%C");
-    mirrorPropAsAssertion("calledThrice", "expected %n to be called thrice but was called %c%C");
-    mirrorPropAsAssertion("calledOn", "expected %n to be called with %1 as this but was called with %t");
-    mirrorPropAsAssertion("alwaysCalledOn", "expected %n to always be called with %1 as this but was called with %t");
+    mirrorPropAsAssertion(
+        "calledOnce",
+        "expected %n to be called once but was called %c%C"
+    );
+    mirrorPropAsAssertion(
+        "calledTwice",
+        "expected %n to be called twice but was called %c%C"
+    );
+    mirrorPropAsAssertion(
+        "calledThrice",
+        "expected %n to be called thrice but was called %c%C"
+    );
+    mirrorPropAsAssertion(
+        "calledOn",
+        "expected %n to be called with %1 as this but was called with %t"
+    );
+    mirrorPropAsAssertion(
+        "alwaysCalledOn",
+        "expected %n to always be called with %1 as this but was called with %t"
+    );
     mirrorPropAsAssertion("calledWithNew", "expected %n to be called with new");
-    mirrorPropAsAssertion("alwaysCalledWithNew", "expected %n to always be called with new");
-    mirrorPropAsAssertion("calledWith", "expected %n to be called with arguments %D");
-    mirrorPropAsAssertion("calledWithMatch", "expected %n to be called with match %D");
-    mirrorPropAsAssertion("alwaysCalledWith", "expected %n to always be called with arguments %D");
-    mirrorPropAsAssertion("alwaysCalledWithMatch", "expected %n to always be called with match %D");
-    mirrorPropAsAssertion("calledWithExactly", "expected %n to be called with exact arguments %D");
-    mirrorPropAsAssertion("calledOnceWithExactly", "expected %n to be called once and with exact arguments %D");
-    mirrorPropAsAssertion("calledOnceWithMatch", "expected %n to be called once and with match %D");
-    mirrorPropAsAssertion("alwaysCalledWithExactly", "expected %n to always be called with exact arguments %D");
-    mirrorPropAsAssertion("neverCalledWith", "expected %n to never be called with arguments %*%C");
-    mirrorPropAsAssertion("neverCalledWithMatch", "expected %n to never be called with match %*%C");
+    mirrorPropAsAssertion(
+        "alwaysCalledWithNew",
+        "expected %n to always be called with new"
+    );
+    mirrorPropAsAssertion(
+        "calledWith",
+        "expected %n to be called with arguments %D"
+    );
+    mirrorPropAsAssertion(
+        "calledWithMatch",
+        "expected %n to be called with match %D"
+    );
+    mirrorPropAsAssertion(
+        "alwaysCalledWith",
+        "expected %n to always be called with arguments %D"
+    );
+    mirrorPropAsAssertion(
+        "alwaysCalledWithMatch",
+        "expected %n to always be called with match %D"
+    );
+    mirrorPropAsAssertion(
+        "calledWithExactly",
+        "expected %n to be called with exact arguments %D"
+    );
+    mirrorPropAsAssertion(
+        "calledOnceWithExactly",
+        "expected %n to be called once and with exact arguments %D"
+    );
+    mirrorPropAsAssertion(
+        "calledOnceWithMatch",
+        "expected %n to be called once and with match %D"
+    );
+    mirrorPropAsAssertion(
+        "alwaysCalledWithExactly",
+        "expected %n to always be called with exact arguments %D"
+    );
+    mirrorPropAsAssertion(
+        "neverCalledWith",
+        "expected %n to never be called with arguments %*%C"
+    );
+    mirrorPropAsAssertion(
+        "neverCalledWithMatch",
+        "expected %n to never be called with match %*%C"
+    );
     mirrorPropAsAssertion("threw", "%n did not throw exception%C");
     mirrorPropAsAssertion("alwaysThrew", "%n did not always throw exception%C");
 
