@@ -2,11 +2,15 @@
 
 var walk = require("./util/core/walk");
 var getPropertyDescriptor = require("./util/core/get-property-descriptor");
-var hasOwnProperty = require("@sinonjs/commons").prototypes.object.hasOwnProperty;
+var hasOwnProperty =
+    require("@sinonjs/commons").prototypes.object.hasOwnProperty;
 var push = require("@sinonjs/commons").prototypes.array.push;
 
 function collectMethod(methods, object, prop, propOwner) {
-    if (typeof getPropertyDescriptor(propOwner, prop).value === "function" && hasOwnProperty(object, prop)) {
+    if (
+        typeof getPropertyDescriptor(propOwner, prop).value === "function" &&
+        hasOwnProperty(object, prop)
+    ) {
         push(methods, object[prop]);
     }
 }
